==> sovix-0.0.1.5.tar.gz: sovix-0.0.1.5/websrc/Customize.php <==
<?php /* Copyright (C) 2006, 2007 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007 David Englund.
This entire article is distributed under the GNU Free Documentation
License, Version 1.2 or any later version.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<?php $sovix__action = $_POST['sovix__action']; $_SESSION['sovix__action']=$sovix__action;

if (empty($sovix__action)) { ?>

<form  method="post"><address>
<table>
<tr>
<td>Media  </td>
<td>
<select name="sovix__media">
<option value="all" <?php if ($sovix__media=="all" || $_SESSION['sovix__media']=="all") echo " selected=\"selected\""; ?>>All </option>
<option value="aural" <?php if ($sovix__media=="aural" || $_SESSION['sovix__media']=="aural") echo " selected=\"selected\""; ?>>aural </option>
<option value="braille" <?php if ($sovix__media=="braille" || $_SESSION['sovix__media']=="braille") echo " selected=\"selected\""; ?>>braille </option>
<option value="embossed" <?php if ($sovix__media=="embossed" || $_SESSION['sovix__media']=="embossed") echo " selected=\"selected\""; ?>>embossed </option>
<option value="handheld" <?php if ($sovix__media=="handheld" || $_SESSION['sovix__media']=="handheld") echo " selected=\"selected\""; ?>>handheld </option>
<option value="print" <?php if ($sovix__media=="print" || $_SESSION['sovix__media']=="print") echo " selected=\"selected\""; ?>>print </option>
<option value="projection" <?php if ($sovix__media=="projection" || $_SESSION['sovix__media']=="projection") echo " selected=\"selected\""; ?>>projection </option>
<option value="screen" <?php if ($sovix__media=="screen" || $_SESSION['sovix__media']=="screen") echo " selected=\"selected\""; ?>>screen </option>
<option value="tty" <?php if ($sovix__media=="tty" || $_SESSION['sovix__media']=="tty") echo " selected=\"selected\""; ?>>tty </option>
<option value="tv" <?php if ($sovix__media=="tv" || $_SESSION['sovix__media']=="tv") echo " selected=\"selected\""; ?>>tv </option>
<option value="presentation" <?php if ($sovix__media=="presentation" || $_SESSION['sovix__media']=="presentation") echo " selected=\"selected\""; ?>>presentation </option>
</select>
</td>
</tr>
<tr>
<td>Font  </td>
<td>
<select name="sovix__fontfamily">    
<option value="Verdana, Arial, Helvetica, sans-serif" <?php if ($sovix__fontfamily=="Verdana, Arial, Helvetica, sans-serif" || $_SESSION['sovix__fontfamily']=="Verdana, Arial, Helvetica, sans-serif") echo " selected=\"selected\""; ?>>Verdana, Arial, Helvetica, sans-serif </option>
<option value="Arial" <?php if ($sovix__fontfamily=="Arial" || $_SESSION['sovix__fontfamily']=="Arial") echo " selected=\"selected\""; ?>>Arial </option>
<option value="Georgia" <?php if ($sovix__fontfamily=="Georgia" || $_SESSION['sovix__fontfamily']=="Georgia") echo " selected=\"selected\""; ?>>Georgia </option>
<option value="Geneva" <?php if ($sovix__fontfamily=="Geneva" || $_SESSION['sovix__fontfamily']=="Geneva") echo " selected=\"selected\""; ?>>Geneva </option>
<option value="Times" <?php if ($sovix__fontfamily=="Times" || $_SESSION['sovix__fontfamily']=="Times") echo " selected=\"selected\""; ?>>Times </option>
<option value="Courier" <?php if ($sovix__fontfamily=="Courier" || $_SESSION['sovix__fontfamily']=="Courier") echo " selected=\"selected\""; ?>>Courier </option>
</select>
</td>
</tr>
<tr>
<td>
Font size  </td>
<td>
<input type="text" value="<?php if (empty($_SESSION['sovix__font_size'])) echo $sovix__font_size; else echo $_SESSION['sovix__font_size']; ?>" size="3" />
<select name="sovix__font_size_type">
<option value="em" <?php if ($sovix__font_size_type=="em" && (empty($_SESSION['sovix__font_size_type'])) || $_SESSION['sovix__font_size_type']=="em") echo " selected=\"selected\""; ?>>em </option>
<option value="%" <?php if ($sovix__font_size_type=="%" && (empty($_SESSION['sovix__font_size_type'])) || $_SESSION['sovix__font_size_type']=="%") echo " selected=\"selected\""; ?>>% </option>
</select>
</td>
</tr>
<tr>
<td>
Width  </td>
<td>
<input type="text" name="sovix__width" value="<?php if (empty($_SESSION['sovix__width'])) echo $sovix__width; else echo $_SESSION['sovix__width']; ?>" size="5" />
</td>
</tr>
<tr>
<td>Background color  </td>
<td>
<input type="text" name="sovix__background_color" value="<?php if (empty($_SESSION['sovix__background_color'])) echo $sovix__background_color; else echo $_SESSION['sovix__background_color']; ?>" size="10" />
</td>
</tr>
<tr>
<td>Foreground color  </td>
<td>
<input type="text" name="sovix__foreground_color" value="<?php if (empty($_SESSION['sovix__foreground_color'])) echo $sovix__foreground_color; else echo $_SESSION['sovix__foreground_color']; ?>" size="10" />
</td>
</tr>
<tr>
<td>  </td>
<td>
<p></p>
<input type="submit" name="sovix__action" value="submit" />
<input type="submit" name="sovix__action" value="reset" />
</td>
</tr>
</table>
</address></form>

<?php } elseif ($sovix__action=="submit") {

$sovix__media = $_POST['sovix__media']; $_SESSION['sovix__media']=$sovix__media;
$sovix__fontfamily = $_POST['sovix__fontfamily']; $_SESSION['sovix__fontfamily']=$sovix__fontfamily;
$sovix__font_size = $_POST['sovix__font_size']; $_SESSION['sovix__font_size']=$sovix__font_size;
$sovix__font_size_type = $_POST['sovix__font_size_type']; $_SESSION['sovix__font_size_type']=$sovix__font_size_type;
$sovix__width = $_POST['sovix__width']; $_SESSION['sovix__width']=$sovix__width;
$sovix__width_type = $_POST['sovix__width_type']; $_SESSION['sovix__width_type']=$sovix__width_type;

$sovix__background_color = $_POST['sovix__background_color']; $_SESSION['sovix__background_color']=$sovix__background_color;
$sovix__foreground_color = $_POST['sovix__foreground_color']; $_SESSION['sovix__foreground_color']=$sovix__foreground_color;

echo "Width is set to: "; echo $_SESSION['sovix__width'];

																					      } elseif ($sovix__action=="reset") {

unset($_SESSION['sovix__media']);
unset($_SESSION['sovix__fontfamily']);
unset($_SESSION['sovix__font_size']);
unset($_SESSION['sovix__font_size_type']);
unset($_SESSION['sovix__width']);

unset($_SESSION['sovix__background_color']);
unset($_SESSION['sovix__foreground_color']);

echo "All customization sessions has ben unregistred.";

 }
?> 

<?php require_once "$sovix__directory__src/footer.inc"; ?>

==> sovix-0.0.1.6.tar.gz: sovix-0.0.1.6/websrc/Customize.php <==
<?php /* Copyright (C) 2006, 2007 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007 David Englund.
Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.2 or any
later version published by the Free Software Foundation; with no Invariant
Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<?php $sovix__action = $_POST['sovix__action']; $_SESSION['sovix__action']=$sovix__action;

if (empty($sovix__action)) { ?>

<form  method="post"><address>
<table>
<tr>
<td>Media  </td>
<td>
<select name="sovix__media">
<option value="all" <?php if ($sovix__media=="all" || $_SESSION['sovix__media']=="all") echo " selected=\"selected\""; ?>>All </option>
<option value="aural" <?php if ($sovix__media=="aural" || $_SESSION['sovix__media']=="aural") echo " selected=\"selected\""; ?>>aural </option>
<option value="braille" <?php if ($sovix__media=="braille" || $_SESSION['sovix__media']=="braille") echo " selected=\"selected\""; ?>>braille </option>
<option value="embossed" <?php if ($sovix__media=="embossed" || $_SESSION['sovix__media']=="embossed") echo " selected=\"selected\""; ?>>embossed </option>
<option value="handheld" <?php if ($sovix__media=="handheld" || $_SESSION['sovix__media']=="handheld") echo " selected=\"selected\""; ?>>handheld </option>
<option value="print" <?php if ($sovix__media=="print" || $_SESSION['sovix__media']=="print") echo " selected=\"selected\""; ?>>print </option>
<option value="projection" <?php if ($sovix__media=="projection" || $_SESSION['sovix__media']=="projection") echo " selected=\"selected\""; ?>>projection </option>
<option value="screen" <?php if ($sovix__media=="screen" || $_SESSION['sovix__media']=="screen") echo " selected=\"selected\""; ?>>screen </option>
<option value="tty" <?php if ($sovix__media=="tty" || $_SESSION['sovix__media']=="tty") echo " selected=\"selected\""; ?>>tty </option>
<option value="tv" <?php if ($sovix__media=="tv" || $_SESSION['sovix__media']=="tv") echo " selected=\"selected\""; ?>>tv </option>
<option value="presentation" <?php if ($sovix__media=="presentation" || $_SESSION['sovix__media']=="presentation") echo " selected=\"selected\""; ?>>presentation </option>
</select>
</td>
</tr>
<tr>
<td>Font  </td>
<td>
<select name="sovix__fontfamily">    
<option value="Verdana, Arial, Helvetica, sans-serif" <?php if ($sovix__fontfamily=="Verdana, Arial, Helvetica, sans-serif" || $_SESSION['sovix__fontfamily']=="Verdana, Arial, Helvetica, sans-serif") echo " selected=\"selected\""; ?>>Verdana, Arial, Helvetica, sans-serif </option>
<option value="Arial" <?php if ($sovix__fontfamily=="Arial" || $_SESSION['sovix__fontfamily']=="Arial") echo " selected=\"selected\""; ?>>Arial </option>
<option value="Georgia" <?php if ($sovix__fontfamily=="Georgia" || $_SESSION['sovix__fontfamily']=="Georgia") echo " selected=\"selected\""; ?>>Georgia </option>
<option value="Geneva" <?php if ($sovix__fontfamily=="Geneva" || $_SESSION['sovix__fontfamily']=="Geneva") echo " selected=\"selected\""; ?>>Geneva </option>
<option value="Times" <?php if ($sovix__fontfamily=="Times" || $_SESSION['sovix__fontfamily']=="Times") echo " selected=\"selected\""; ?>>Times </option>
<option value="Courier" <?php if ($sovix__fontfamily=="Courier" || $_SESSION['sovix__fontfamily']=="Courier") echo " selected=\"selected\""; ?>>Courier </option>
</select>
</td>
</tr>
<tr>
<td>
Font size  </td>
<td>
<input type="text" value="<?php if (empty($_SESSION['sovix__font_size'])) echo $sovix__font_size; else echo $_SESSION['sovix__font_size']; ?>" size="3" />
<select name="sovix__font_size_type">
<option value="em" <?php if ($sovix__font_size_type=="em" && (empty($_SESSION['sovix__font_size_type'])) || $_SESSION['sovix__font_size_type']=="em") echo " selected=\"selected\""; ?>>em </option>
<option value="%" <?php if ($sovix__font_size_type=="%" && (empty($_SESSION['sovix__font_size_type'])) || $_SESSION['sovix__font_size_type']=="%") echo " selected=\"selected\""; ?>>% </option>
</select>
</td>
</tr>
<tr>
<td>
Width  </td>
<td>
<input type="text" name="sovix__width" value="<?php if (empty($_SESSION['sovix__width'])) echo $sovix__width; else echo $_SESSION['sovix__width']; ?>" size="5" />
</td>
</tr>
<tr>
<td>Background color  </td>
<td>
<input type="text" name="sovix__background_color" value="<?php if (empty($_SESSION['sovix__background_color'])) echo $sovix__background_color; else echo $_SESSION['sovix__background_color']; ?>" size="10" />
</td>
</tr>
<tr>
<td>Foreground color  </td>
<td>
<input type="text" name="sovix__foreground_color" value="<?php if (empty($_SESSION['sovix__foreground_color'])) echo $sovix__foreground_color; else echo $_SESSION['sovix__foreground_color']; ?>" size="10" />
</td>
</tr>
<tr>
<td>  </td>
<td>
<p></p>
<input type="submit" name="sovix__action" value="submit" />
<input type="submit" name="sovix__action" value="reset" />
</td>
</tr>
</table>
</address></form>

<?php } elseif ($sovix__action=="submit") {

$sovix__media = $_POST['sovix__media']; $_SESSION['sovix__media']=$sovix__media;
$sovix__fontfamily = $_POST['sovix__fontfamily']; $_SESSION['sovix__fontfamily']=$sovix__fontfamily;
$sovix__font_size = $_POST['sovix__font_size']; $_SESSION['sovix__font_size']=$sovix__font_size;
$sovix__font_size_type = $_POST['sovix__font_size_type']; $_SESSION['sovix__font_size_type']=$sovix__font_size_type;
$sovix__width = $_POST['sovix__width']; $_SESSION['sovix__width']=$sovix__width;
$sovix__width_type = $_POST['sovix__width_type']; $_SESSION['sovix__width_type']=$sovix__width_type;

$sovix__background_color = $_POST['sovix__background_color']; $_SESSION['sovix__background_color']=$sovix__background_color;
$sovix__foreground_color = $_POST['sovix__foreground_color']; $_SESSION['sovix__foreground_color']=$sovix__foreground_color;

echo "Width is set to: "; echo $_SESSION['sovix__width'];

																					      } elseif ($sovix__action=="reset") {

unset($_SESSION['sovix__media']);
unset($_SESSION['sovix__fontfamily']);
unset($_SESSION['sovix__font_size']);
unset($_SESSION['sovix__font_size_type']);
unset($_SESSION['sovix__width']);

unset($_SESSION['sovix__background_color']);
unset($_SESSION['sovix__foreground_color']);

echo "All customization sessions has ben unregistred.";

 }
?> 

<?php require_once "$sovix__directory__src/footer.inc"; ?>
